coldp.IdentifierPolicy
======================

.. currentmodule:: coldp

Class
~~~~~

.. automethod:: coldp.IdentifierPolicy.__init__

Methods
~~~~~~~

.. automethod:: coldp.IdentifierPolicy.initialise
.. automethod:: coldp.IdentifierPolicy.next

Index and search 
~~~~~~~~~~~~~~~~

* :ref:`genindex`
* :ref:`search`
